@@ -22,6 +22,18 @@ SECTOR_BM_DEFAULT = {
      'UTILITIES': 'NIFTY CONSUMPTION'
 }
 
+INDICES = list(set(SECTOR_BM_DEFAULT.values())) + [
+    'NIFTY 50', 
+    'NIFTY 100', 
+    'NIFTY MIDCAP 100', 
+    'NIFTY SMLCAP 100',
+    'NIFTY CONSUMER DURABLES',
+    'NIFTY BANK',
+    'NIFTY PVT BANK',
+    'NIFTY PSU BANK',
+    'NIFTY100 ENHANCED ESG'
+]
+
 SAA_ASSET_ALLOCATION = 'SAA Asset Allocation'
 ASSET_ALLOCATION = 'Asset Allocation'
 BENCHMARK_ALLOCATION = 'Benchmark Allocation'
